@@ -1,4 +1,3 @@
-static const char *RcsId = "$Header$";
 //+=============================================================================
 //
 // file :         DataBaseUtils.cpp
@@ -29,20 +28,12 @@ static const char *RcsId = "$Header$";
 // You should have received a copy of the GNU General Public License
 // along with Tango.  If not, see <http://www.gnu.org/licenses/>.
 //
-// $Revision$
-// $Date$
-//
-// $HeadURL:$
-//
 //=============================================================================
 
-#if HAVE_CONFIG_H
-#include <ac_config.h>
-#endif
-
-#include <tango.h>
-#include <DataBase.h>
-#include <DataBaseClass.h>
+#include <tango/tango.h>
+#include "DataBase.h"
+#include "DataBaseClass.h"
+#include "Logging.h"
 
 #include <errmsg.h>
 
@@ -50,6 +41,11 @@ static const char *RcsId = "$Header$";
 
 #ifdef _TG_WINDOWS_
 #include <ws2tcpip.h>
+#include <windows.h>
+static inline void sleep(DWORD seconds)
+{
+    Sleep(seconds * 1000);
+}
 #else
 #include <arpa/inet.h>
 #include <sys/socket.h>
@@ -57,8 +53,6 @@ static const char *RcsId = "$Header$";
 #include <netinet/in.h>
 #endif
 
-using namespace std;
-
 namespace DataBase_ns {
 
 //+----------------------------------------------------------------------------
@@ -74,16 +68,16 @@ namespace DataBase_ns {
 // out :		void - nothing
 //
 //-----------------------------------------------------------------------------
-string DataBase::replace_wildcard(const char *wildcard_c_str)
+std::string DataBase::replace_wildcard(const char *wildcard_c_str)
 {
-	string wildcard(wildcard_c_str);
-	string::size_type index;
+	std::string wildcard(wildcard_c_str);
+	std::string::size_type index;
 
-	DEBUG_STREAM << "DataBase::replace_wildcard() wildcard in " << wildcard << endl;
+	DEBUG_STREAM << "DataBase::replace_wildcard() wildcard in " << wildcard << std::endl;
 // escape %
 
 	index = 0;
-	while ((index = wildcard.find('%',index)) != string::npos)
+	while ((index = wildcard.find('%',index)) != std::string::npos)
 	{
 		wildcard.insert(index, 1, '\\');
 		index = index+2;
@@ -92,7 +86,7 @@ string DataBase::replace_wildcard(const char *wildcard_c_str)
 // escape _
 
 	index = 0;
-	while ((index = wildcard.find('_',index)) != string::npos)
+	while ((index = wildcard.find('_',index)) != std::string::npos)
 	{
 		wildcard.insert(index, 1, '\\');
 		index = index+2;
@@ -102,7 +96,7 @@ string DataBase::replace_wildcard(const char *wildcard_c_str)
 // escape "
 
 	index = 0;
-	while ((index = wildcard.find('"',index)) != string::npos)
+	while ((index = wildcard.find('"',index)) != std::string::npos)
 	{
 		wildcard.insert(index, 1, '\\');
 		index = index+2;
@@ -112,7 +106,7 @@ string DataBase::replace_wildcard(const char *wildcard_c_str)
 // escape '
 
 	index = 0;
-	while ((index = wildcard.find('\'',index)) != string::npos)
+	while ((index = wildcard.find('\'',index)) != std::string::npos)
 	{
 		wildcard.insert(index, 1, '\\');
 		index = index+2;
@@ -120,12 +114,12 @@ string DataBase::replace_wildcard(const char *wildcard_c_str)
 
 // replace wildcard * with %
 
-	while ((index = wildcard.find('*')) != string::npos)
+	while ((index = wildcard.find('*')) != std::string::npos)
 	{
 		wildcard.replace(index, 1, 1, '%');
 	}
 
-	DEBUG_STREAM << "DataBase::replace_wildcard() wildcard out " << wildcard << endl;
+	DEBUG_STREAM << "DataBase::replace_wildcard() wildcard out " << wildcard << std::endl;
 	return wildcard;
 }
 
@@ -141,19 +135,19 @@ string DataBase::replace_wildcard(const char *wildcard_c_str)
 // out :		string - The result string .
 //
 //-----------------------------------------------------------------------------
-string DataBase::escape_string(const char *string_c_str)
+std::string DataBase::escape_string(const char *string_c_str)
 {
-	string escaped_string(string_c_str);
-	string::size_type index;
+	std::string escaped_string(string_c_str);
+	std::string::size_type index;
 
-	DEBUG_STREAM << "DataBase::escape_string() string in : " << escaped_string << endl;
+	DEBUG_STREAM << "DataBase::escape_string() string in : " << escaped_string << std::endl;
 
 	//	escape bakckslash
 	index = 0;
-	while ((index = escaped_string.find('\\',index)) != string::npos)
+	while ((index = escaped_string.find('\\',index)) != std::string::npos)
 	{
 		//	Check if double backslash already treated by client
-		string	s = escaped_string.substr(index+1);
+		std::string	s = escaped_string.substr(index+1);
 
 			//	Check if another escape sequence treated by client
 		if (s.find('\"')==0 || s.find('\'')==0)
@@ -167,7 +161,7 @@ string DataBase::escape_string(const char *string_c_str)
 
 	//	escape "
 	index = 0;
-	while ((index = escaped_string.find('"',index)) != string::npos)
+	while ((index = escaped_string.find('"',index)) != std::string::npos)
 	{
 		if (index==0)	//	Cannot have '\' at -1 !
 		{
@@ -177,7 +171,7 @@ string DataBase::escape_string(const char *string_c_str)
 		else
 		{
 			//	Check if double quotes already treated by client
-			string	s = escaped_string.substr(index-1);
+			std::string	s = escaped_string.substr(index-1);
 			if (s.find('\\')==0)
 				index++;
 			else
@@ -191,7 +185,7 @@ string DataBase::escape_string(const char *string_c_str)
 
 	//	escape '
 	index = 0;
-	while ((index = escaped_string.find('\'',index)) != string::npos)
+	while ((index = escaped_string.find('\'',index)) != std::string::npos)
 	{
 		if (index==0)	//	Cannot have '\' at -1 !
 		{
@@ -201,7 +195,7 @@ string DataBase::escape_string(const char *string_c_str)
 		else
 		{
 			//	Check if simple quotes already treated by client
-			string	s = escaped_string.substr(index-1);
+			std::string	s = escaped_string.substr(index-1);
 			if (s.find('\\')==0)
 				index++;
 			else
@@ -212,13 +206,13 @@ string DataBase::escape_string(const char *string_c_str)
 		}
 	}
 
-	DEBUG_STREAM << "DataBase::escaped_string() wildcard out : " << escaped_string << endl;
+	DEBUG_STREAM << "DataBase::escaped_string() wildcard out : " << escaped_string << std::endl;
 	return escaped_string;
 }
 
 //+----------------------------------------------------------------------------
 //
-// method : 		DataBase::device_name_to_dfm(string &device_name,
+// method : 		DataBase::device_name_to_dfm(std::string &device_name,
 //			          char **domain, char **family, char **member)
 //
 // description : 	utility function to return domain, family and member
@@ -231,11 +225,11 @@ string DataBase::escape_string(const char *string_c_str)
 // out :		bool - true or false
 //
 //-----------------------------------------------------------------------------
-bool DataBase::device_name_to_dfm(string &devname, char domain[], char family[], char member[])
+bool DataBase::device_name_to_dfm(std::string &devname, char domain[], char family[], char member[])
 {
-	string::size_type index, index2;
+	std::string::size_type index, index2;
 
-	DEBUG_STREAM << "DataBase::device_name_to_dfm() device name in " << devname << endl;
+	DEBUG_STREAM << "DataBase::device_name_to_dfm() device name in " << devname << std::endl;
 
 	index = devname.find('/');
 	index2 = devname.find('/', index+1);
@@ -249,14 +243,14 @@ bool DataBase::device_name_to_dfm(string &devname, char domain[], char family[],
 	(devname.substr(index2+1)).copy(member,devname.length()-index2);
 	member[devname.length()-index2-1] = '\0';
 
-	DEBUG_STREAM << "DataBase::device_name_to_dfm() domain/family/member out " << domain << "/" << family << "/" << member << endl;
+	DEBUG_STREAM << "DataBase::device_name_to_dfm() domain/family/member out " << domain << "/" << family << "/" << member << std::endl;
 
 	return true;
 }
 
 //+----------------------------------------------------------------------------
 //
-// method : 		DataBase::check_device_name(string *device_name)
+// method : 		DataBase::check_device_name(std::string *device_name)
 //
 // description : 	utility function to check whether device name conforms
 //			to the TANGO naming convention of
@@ -268,17 +262,17 @@ bool DataBase::device_name_to_dfm(string &devname, char domain[], char family[],
 // out :		bool - true or false
 //
 //-----------------------------------------------------------------------------
-bool DataBase::check_device_name(string &device_name_str)
+bool DataBase::check_device_name(std::string &device_name_str)
 {
-	string devname(device_name_str);
-	string::size_type index, index2;
+	std::string devname(device_name_str);
+	std::string::size_type index, index2;
 
-	DEBUG_STREAM << "DataBase::check_device_name(): device_name in " << devname << endl;
+	DEBUG_STREAM << "DataBase::check_device_name(): device_name in " << devname << std::endl;
 
 // check there are no special characters which could be interpreted
 // as wildcards or which are otherwise excluded
 
-	if (devname.find('*') != string::npos) return false;
+	if (devname.find('*') != std::string::npos) return false;
 
 // check protocol - "tango:" | "taco:"
 
@@ -298,8 +292,8 @@ bool DataBase::check_device_name(string &device_name_str)
 
 	if (devname.substr(0,2) == "//")
 	{
-		index = devname.find('/',(string::size_type)2);
-		if (index == 0 || index == string::npos)
+		index = devname.find('/',(std::string::size_type)2);
+		if (index == 0 || index == std::string::npos)
 		{
 			return false;
 
@@ -312,7 +306,7 @@ bool DataBase::check_device_name(string &device_name_str)
 	index = devname.find('/');
 	index2 = devname.find('/',index+1);
 
-	if (index == 0 || index == string::npos || index2 == string::npos ||
+	if (index == 0 || index == std::string::npos || index2 == std::string::npos ||
 	    index2-index <= 0 || devname.length() - index2 <= 0)
 	{
 		return false;
@@ -320,7 +314,7 @@ bool DataBase::check_device_name(string &device_name_str)
 
 	device_name_str = devname;
 
-	DEBUG_STREAM << "DataBase::check_device_name(): device_name out " << device_name_str << endl;
+	DEBUG_STREAM << "DataBase::check_device_name(): device_name out " << device_name_str << std::endl;
 
 	return true;
 }
@@ -406,11 +400,11 @@ void DataBase::check_history_tables()
 	TangoSys_MemStream	sql_query_stream;
 	MYSQL_RES *result;
 
-	INFO_STREAM << "DataBase::check_history_tables(): entering" << endl;
+	INFO_STREAM << "DataBase::check_history_tables(): entering" << std::endl;
 
 	sql_query_stream.str("");
 	sql_query_stream << "SELECT count(*) FROM property_device_hist";
-	DEBUG_STREAM << "DataBase::check_history_tables(): sql_query " << sql_query_stream.str() << endl;
+	DEBUG_STREAM << "DataBase::check_history_tables(): sql_query " << sql_query_stream.str() << std::endl;
 	result = query(sql_query_stream.str(),"check_history_tables()");
 	mysql_free_result(result);
 }
@@ -445,22 +439,22 @@ Tango::DevULong64 DataBase::get_id(const char *name,int con_nb)
 
     sql_query.str("");
     sql_query << "UPDATE " << name << "_history_id SET id=LAST_INSERT_ID(id+1)";
-	string tmp_str = sql_query.str();
+	std::string tmp_str = sql_query.str();
 
 	if (mysql_real_query(conn_pool[con_nb].db, tmp_str.c_str(),tmp_str.length()) != 0)
 	{
 		TangoSys_OMemStream o;
 
-		WARN_STREAM << "DataBase::get_id() failed to query TANGO database:" << endl;
-		WARN_STREAM << "  query = " << tmp_str << endl;
-		WARN_STREAM << " (SQL error=" << mysql_error(conn_pool[con_nb].db) << ")" << endl;
+		WARN_STREAM << "DataBase::get_id() failed to query TANGO database:" << std::endl;
+		WARN_STREAM << "  query = " << tmp_str << std::endl;
+		WARN_STREAM << " (SQL error=" << mysql_error(conn_pool[con_nb].db) << ")" << std::endl;
 
-		o << "Failed to query TANGO database (error=" << mysql_error(conn_pool[con_nb].db) << ")" << ends;
+		o << "Failed to query TANGO database (error=" << mysql_error(conn_pool[con_nb].db) << ")" << std::ends;
 
 		if (need_release == true)
 			release_connection(con_nb);
 
-		Tango::Except::throw_exception((const char *)DB_SQLError,o.str(),(const char *)"DataBase::get_id()");
+		Tango::Except::throw_exception(DB_SQLError,o.str(),"DataBase::get_id()");
 	}
 
 	my_ulonglong val = mysql_insert_id(conn_pool[con_nb].db);
@@ -473,7 +467,7 @@ Tango::DevULong64 DataBase::get_id(const char *name,int con_nb)
 		if (need_release == true)
 			release_connection(con_nb);
 
-		Tango::Except::throw_exception((const char *)DB_SQLError,o.str(),(const char *)"DataBase::get_id()");
+		Tango::Except::throw_exception(DB_SQLError,o.str(),"DataBase::get_id()");
 	}
 
 	if (need_release == true)
@@ -489,7 +483,7 @@ Tango::DevULong64 DataBase::get_id(const char *name,int con_nb)
 // description : 	Execute a SQL query , ignore the result.
 //
 //-----------------------------------------------------------------------------
-void DataBase::simple_query(string sql_query,const char *method,int con_nb)
+void DataBase::simple_query(std::string sql_query,const char *method,int con_nb)
 {
 
 //
@@ -505,7 +499,7 @@ void DataBase::simple_query(string sql_query,const char *method,int con_nb)
 		need_release = true;
 	}
 
-	DEBUG_STREAM << "Using MySQL connection with semaphore " << con_nb << endl;
+	DEBUG_STREAM << "Using MySQL connection with semaphore " << con_nb << std::endl;
 
 //
 // Call MySQL
@@ -516,18 +510,18 @@ void DataBase::simple_query(string sql_query,const char *method,int con_nb)
 		TangoSys_OMemStream o;
 		TangoSys_OMemStream o2;
 
-		WARN_STREAM << "DataBase::" << method << " failed to query TANGO database:" << endl;
-		WARN_STREAM << "  query = " << sql_query << endl;
-		WARN_STREAM << " (SQL error=" << mysql_error(conn_pool[con_nb].db) << ")" << endl;
+		WARN_STREAM << "DataBase::" << method << " failed to query TANGO database:" << std::endl;
+		WARN_STREAM << "  query = " << sql_query << std::endl;
+		WARN_STREAM << " (SQL error=" << mysql_error(conn_pool[con_nb].db) << ")" << std::endl;
 
 		o << "Failed to query TANGO database (error=" << mysql_error(conn_pool[con_nb].db) << ")";
-		o << "\n.The query was: " << sql_query << ends;
-		o2 << "DataBase::" << method << ends;
+		o << "\n.The query was: " << sql_query << std::ends;
+		o2 << "DataBase::" << method << std::ends;
 
 		if (need_release == true)
 			release_connection(con_nb);
 
-		Tango::Except::throw_exception((const char *)DB_SQLError,o.str(),o2.str());
+		Tango::Except::throw_exception(DB_SQLError,o.str(),o2.str());
 	}
 
 	if (need_release)
@@ -542,7 +536,7 @@ void DataBase::simple_query(string sql_query,const char *method,int con_nb)
 // description : 	Execute a SQL query and return the result.
 //
 //-----------------------------------------------------------------------------
-MYSQL_RES *DataBase::query(string sql_query,const char *method,int con_nb)
+MYSQL_RES *DataBase::query(std::string sql_query,const char *method,int con_nb)
 {
 	MYSQL_RES *result;
 
@@ -559,7 +553,7 @@ MYSQL_RES *DataBase::query(string sql_query,const char *method,int con_nb)
 		need_release = true;
 	}
 
-	DEBUG_STREAM << "Using MySQL connection with semaphore " << con_nb << endl;
+	DEBUG_STREAM << "Using MySQL connection with semaphore " << con_nb << std::endl;
 
 //
 // Call MySQL
@@ -570,18 +564,18 @@ MYSQL_RES *DataBase::query(string sql_query,const char *method,int con_nb)
 		TangoSys_OMemStream o;
 		TangoSys_OMemStream o2;
 
-		WARN_STREAM << "DataBase::" << method << " failed to query TANGO database:" << endl;
-		WARN_STREAM << "  query = " << sql_query << endl;
-		WARN_STREAM << " (SQL error=" << mysql_error(conn_pool[con_nb].db) << ")" << endl;
+		WARN_STREAM << "DataBase::" << method << " failed to query TANGO database:" << std::endl;
+		WARN_STREAM << "  query = " << sql_query << std::endl;
+		WARN_STREAM << " (SQL error=" << mysql_error(conn_pool[con_nb].db) << ")" << std::endl;
 
 		o << "Failed to query TANGO database (error=" << mysql_error(conn_pool[con_nb].db) << ")";
-		o << "\nThe query was: " << sql_query << ends;
-		o2 << "DataBase::" << method << ends;
+		o << "\nThe query was: " << sql_query << std::ends;
+		o2 << "DataBase::" << method << std::ends;
 
 		if (need_release == true)
 			release_connection(con_nb);
 
-		Tango::Except::throw_exception((const char *)DB_SQLError,o.str(),o2.str());
+		Tango::Except::throw_exception(DB_SQLError,o.str(),o2.str());
 	}
 
 	if ((result = mysql_store_result(conn_pool[con_nb].db)) == NULL)
@@ -589,7 +583,7 @@ MYSQL_RES *DataBase::query(string sql_query,const char *method,int con_nb)
 		TangoSys_OMemStream o;
 		TangoSys_OMemStream o2;
 
-		WARN_STREAM << "DataBase:: " << method << " : mysql_store_result() failed  (error=" << mysql_error(conn_pool[con_nb].db) << ")" << endl;
+		WARN_STREAM << "DataBase:: " << method << " : mysql_store_result() failed  (error=" << mysql_error(conn_pool[con_nb].db) << ")" << std::endl;
 
 		o << "mysql_store_result() failed (error=" << mysql_error(conn_pool[con_nb].db) << ")";
 		o2 << "DataBase::" << method;
@@ -597,7 +591,7 @@ MYSQL_RES *DataBase::query(string sql_query,const char *method,int con_nb)
 		if (need_release == true)
 			release_connection(con_nb);
 
-		Tango::Except::throw_exception((const char *)DB_SQLError,o.str(),o2.str());
+		Tango::Except::throw_exception(DB_SQLError,o.str(),o2.str());
 	}
 
 	if (need_release)
@@ -636,7 +630,7 @@ int DataBase::get_connection()
 					last_sem_wait = 0;
 			}
 			loop = sem_to_wait;
-			WARN_STREAM << "Waiting for one free MySQL connection on semaphore " << loop << endl;
+			WARN_STREAM << "Waiting for one free MySQL connection on semaphore " << loop << std::endl;
 			conn_pool[loop].the_sema.wait();
 			break;
 		}
@@ -696,7 +690,7 @@ void DataBase::purge_att_property(const char *table,const char *field,const char
   MYSQL_RES *result;
   MYSQL_ROW row2;
 
-  //cout << "purge_att_property(" << object << "," << attribute << "," << name << ")" << endl;
+  //TANGO_LOG << "purge_att_property(" << object << "," << attribute << "," << name << ")" << std::endl;
 
   sql_query.str("");
   sql_query << "SELECT DISTINCT id,date FROM " << table
@@ -733,7 +727,7 @@ void DataBase::purge_pipe_property(const char *table,const char *field,const cha
   MYSQL_RES *result;
   MYSQL_ROW row2;
 
-  //cout << "purge_pipe_property(" << object << "," << pipe << "," << name << ")" << endl;
+  //TANGO_LOG << "purge_pipe_property(" << object << "," << pipe << "," << name << ")" << std::endl;
 
   sql_query.str("");
   sql_query << "SELECT DISTINCT id,date FROM " << table
@@ -784,11 +778,11 @@ void DataBase::base_connect(int loop)
 		my_bool my_auto_reconnect=1;
 		if (mysql_options(conn_pool[loop].db,MYSQL_OPT_RECONNECT,&my_auto_reconnect) !=0)
 		{
-			ERROR_STREAM << "DataBase: error setting mysql auto reconnection: " << mysql_error(conn_pool[loop].db) << endl;
+			ERROR_STREAM << "DataBase: error setting mysql auto reconnection: " << mysql_error(conn_pool[loop].db) << std::endl;
 		}
 		else
 		{
-			WARN_STREAM << "DataBase: set mysql auto reconnect to true" << endl;
+			WARN_STREAM << "DataBase: set mysql auto reconnect to true" << std::endl;
 		}
 	}
 #endif
@@ -805,25 +799,8 @@ void DataBase::base_connect(int loop)
 
 void DataBase::create_connection_pool(const char *mysql_user,
                                       const char *mysql_password,
-                                      const char *mysql_host,
-                                      const char *mysql_name)
+                                      const char *mysql_host)
 {
-#ifndef HAVE_CONFIG_H
-	char *database = (char *)"tango";
-#else
-	char *database = (char *)TANGO_DB_NAME;
-#endif
-
-//
-// Init MySQL db name (locally and as data member)
-//
-
-    if (mysql_name != NULL)
-    {
-        database = const_cast<char *>(mysql_name);
-    }
-    mysql_db_name = database;
-
 //
 // Check on provided MySQl user and password
 //
@@ -831,25 +808,25 @@ void DataBase::create_connection_pool(const char *mysql_user,
 	if (mysql_user != NULL && mysql_password != NULL)
 	{
 		WARN_STREAM << "DataBase::create_connection_pool(): mysql database user =  " << mysql_user
-	           	 << " , password = " << mysql_password << endl;
+	           	 << " , password = " << mysql_password << std::endl;
 	}
 
 	const char *host;
-	string my_host;
-	string ho,port;
+	std::string my_host;
+	std::string ho,port;
 	unsigned int port_num = 0;
 
 	if (mysql_host != NULL)
 	{
 		my_host = mysql_host;
-		WARN_STREAM << "DataBase::create_connection_pool(): mysql host = " << mysql_host << endl;
-		string::size_type pos = my_host.find(':');
-		if (pos != string::npos)
+		WARN_STREAM << "DataBase::create_connection_pool(): mysql host = " << mysql_host << std::endl;
+		std::string::size_type pos = my_host.find(':');
+		if (pos != std::string::npos)
 		{
 			ho = my_host.substr(0,pos);
 			pos++;
 			port = my_host.substr(pos);
-			stringstream ss(port);
+			std::stringstream ss(port);
 			ss >> port_num;
 			if (!ss)
 				port_num = 0;
@@ -857,7 +834,7 @@ void DataBase::create_connection_pool(const char *mysql_user,
 		}
 		else
 			host = my_host.c_str();
-		WARN_STREAM << "DataBase::create_connection_pool(): mysql host = " << host << ", port = " << port_num << endl;
+		WARN_STREAM << "DataBase::create_connection_pool(): mysql host = " << host << ", port = " << port_num << std::endl;
 	}
 	else
 		host = NULL;
@@ -877,8 +854,8 @@ void DataBase::create_connection_pool(const char *mysql_user,
 //
 
 
-		WARN_STREAM << "Going to connect to MySQL for conn. " << loop << endl;
-		if (!mysql_real_connect(conn_pool[loop].db, host, mysql_user, mysql_password, database, port_num, NULL, CLIENT_MULTI_STATEMENTS | CLIENT_FOUND_ROWS))
+		WARN_STREAM << "Going to connect to MySQL for conn. " << loop << std::endl;
+		if (!mysql_real_connect(conn_pool[loop].db, host, mysql_user, mysql_password, mysql_db_name.c_str(), port_num, NULL, CLIENT_MULTI_STATEMENTS | CLIENT_FOUND_ROWS))
 		{
 			if (loop == 0)
 			{
@@ -887,45 +864,45 @@ void DataBase::create_connection_pool(const char *mysql_user,
 				{
 					sleep(1);
 					int db_err = mysql_errno(conn_pool[loop].db);
-					WARN_STREAM << "Connection to MySQL failed with error " << db_err << endl;
+					WARN_STREAM << "Connection to MySQL failed with error " << db_err << std::endl;
 					if (db_err == CR_CONNECTION_ERROR || db_err == CR_CONN_HOST_ERROR)
 					{
 						mysql_close(conn_pool[loop].db);
 						conn_pool[loop].db = NULL;
 						base_connect(loop);
 					}
-					WARN_STREAM << "Going to retry to connect to MySQL for connection " << loop << endl;
-					if (!mysql_real_connect(conn_pool[loop].db, host, mysql_user, mysql_password, database, port_num, NULL, CLIENT_MULTI_STATEMENTS | CLIENT_FOUND_ROWS))
+					WARN_STREAM << "Going to retry to connect to MySQL for connection " << loop << std::endl;
+					if (!mysql_real_connect(conn_pool[loop].db, host, mysql_user, mysql_password, mysql_db_name.c_str(), port_num, NULL, CLIENT_MULTI_STATEMENTS | CLIENT_FOUND_ROWS))
 					{
-						WARN_STREAM << "Connection to MySQL (re-try) failed with error " << mysql_errno(conn_pool[loop].db) << endl;
+						WARN_STREAM << "Connection to MySQL (re-try) failed with error " << mysql_errno(conn_pool[loop].db) << std::endl;
 						retry--;
 						if (retry == 0)
 						{
-							WARN_STREAM << "Throw exception because no MySQL connection possible after 5 re-tries" << endl;
+							WARN_STREAM << "Throw exception because no MySQL connection possible after 5 re-tries" << std::endl;
 							TangoSys_MemStream out_stream;
-							out_stream << "Failed to connect to TANGO database (error = " << mysql_error(conn_pool[loop].db) << ")" << ends;
+							out_stream << "Failed to connect to TANGO database (error = " << mysql_error(conn_pool[loop].db) << ")" << std::ends;
 
-							Tango::Except::throw_exception((const char *)"CANNOT_CONNECT_MYSQL",
+							Tango::Except::throw_exception("CANNOT_CONNECT_MYSQL",
 												out_stream.str(),
-												(const char *)"DataBase::init_device()");
+												"DataBase::init_device()");
 						}
 					}
 					else
 					{
-						WARN_STREAM << "MySQL connection succeed after retry" << endl;
+						WARN_STREAM << "MySQL connection succeed after retry" << std::endl;
 						retry = 0;
 					}
 				}
 			}
 			else
 			{
-				WARN_STREAM << "Failed to connect to MySQL for conn. " << loop << ". No re-try in this case" << endl;
+				WARN_STREAM << "Failed to connect to MySQL for conn. " << loop << ". No re-try in this case" << std::endl;
 				TangoSys_MemStream out_stream;
-				out_stream << "Failed to connect to TANGO database (error = " << mysql_error(conn_pool[loop].db) << ")" << ends;
+				out_stream << "Failed to connect to TANGO database (error = " << mysql_error(conn_pool[loop].db) << ")" << std::ends;
 
-				Tango::Except::throw_exception((const char *)"CANNOT_CONNECT_MYSQL",
+				Tango::Except::throw_exception("CANNOT_CONNECT_MYSQL",
 												out_stream.str(),
-												(const char *)"DataBase::init_device()");
+												"DataBase::init_device()");
 			}
 		}
 	}
@@ -944,7 +921,7 @@ void DataBase::create_connection_pool(const char *mysql_user,
  */
 //+------------------------------------------------------------------
 
-bool DataBase::host_port_from_ior(const char *iorstr,string &h_p)
+bool DataBase::host_port_from_ior(const char *iorstr,std::string &h_p)
 {
 	size_t s = (iorstr ? strlen(iorstr) : 0);
 
@@ -1032,8 +1009,8 @@ bool DataBase::host_port_from_ior(const char *iorstr,string &h_p)
 				ho = pBody.address.host.in();
 				bool host_is_name = false;
 
-				string::size_type pos = ho.find('.');
-				if (pos == string::npos)
+				std::string::size_type pos = ho.find('.');
+				if (pos == std::string::npos)
 					host_is_name = true;
 				else
 				{
@@ -1076,7 +1053,7 @@ bool DataBase::host_port_from_ior(const char *iorstr,string &h_p)
 				}
 				else
 				{
-					if (pos == string::npos)
+					if (pos == std::string::npos)
 					{
 						Tango::DeviceProxy::get_fqdn(ho);
 					}
@@ -1088,7 +1065,7 @@ bool DataBase::host_port_from_ior(const char *iorstr,string &h_p)
 // Add port number
 //
 
-				stringstream ss;
+				std::stringstream ss;
 				ss << pBody.address.port;
 				h_p = h_p + ss.str();
 
@@ -1139,4 +1116,21 @@ AutoLock::~AutoLock()
 	the_db->release_connection(con_nb);
 }
 
+/// Parse a string to return an integer
+/// Current implementation does not complain about trailing garbage.
+template<>
+int DataBase::ParseString<int>(const char * c_str)
+{
+  int val;
+  const int ret = sscanf(c_str, "%d", &val);
+
+  if(ret != 1 || ret == EOF)
+  {
+    WARN_STREAM << "Could not parse string: " << std::string(c_str) << std::endl;
+    Tango::Except::throw_exception(DB_ParseStringError, "Could not parse string to number", "DataBase::ParseString");
+  }
+
+  return val;
+}
+
 }
