@@ -1,5 +1,3 @@
-static const char *RcsId = "$Id$";
-
 //+============================================================================
 //
 // file :               tango_admin.cpp
@@ -41,17 +39,11 @@ static const char *RcsId = "$Id$";
 // You should have received a copy of the GNU General Public License
 // along with Tango.  If not, see <http://www.gnu.org/licenses/>.
 //
-// $Revision$
-//
 //-============================================================================
 
-#if HAVE_CONFIG_H
-#include <ac_config.h>
-#endif
-
 #include <iostream>
 #include <anyoption.h>
-#include <tango.h>
+#include <tango/tango.h>
 
 #include <time.h>
 #include <sys/types.h>
